# viz3dvideo

Visualize a video of 3D graphs in Matplotlib

[![logo](https://raw.githubusercontent.com/trucomanx/Viz3DVideo/main/screenshot.png)](https://www.youtube.com/watch?v=OSm2YUywPsQ)

## 1. Installing

To install the package from [PyPI](https://pypi.org/project/viz3dvideo/), follow the instructions below:


```bash
pip install --upgrade viz3dvideo
```

Execute `which viz3dvideo-info` to see where it was installed, probably in `/home/USERNAME/.local/bin/viz3dvideo-info`.

### Using

To start, use the command below:

```bash
viz3dvideo-info
```
## 2. More information

If you want more information go to [doc](https://github.com/trucomanx/Viz3DVideo/blob/main/doc) directory.

## 3. Buy me a coffee

If you find this tool useful and would like to support its development, you can buy me a coffee!  
Your donations help keep the project running and improve future updates.  

[☕ Buy me a coffee](https://ko-fi.com/trucomanx) 

## 4. License

This project is licensed under the GPL license. See the `LICENSE` file for more details.
